# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: secret_engine_types.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2
from . import tags_pb2 as tags__pb2
from . import secret_engine_policy_pb2 as secret__engine__policy__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19secret_engine_types.proto\x12\x02v1\x1a\roptions.proto\x1a\ntags.proto\x1a\x1asecret_engine_policy.proto\x1a\x1egoogle/protobuf/duration.proto\"\xf5\x04\n\x0cSecretEngine\x12q\n\x10\x61\x63tive_directory\x18\xcc\x02 \x01(\x0b\x32\x19.v1.ActiveDirectoryEngineB9\xf2\xf8\xb3\x07*\xca\xf3\xb3\x07%\xc2\xf4\xb3\x07 \n\x0cjson_gateway\x12\x10\x61\x63tive_directory\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12\\\n\tkey_value\x18\xcb\x02 \x01(\x0b\x32\x12.v1.KeyValueEngineB2\xf2\xf8\xb3\x07#\xca\xf3\xb3\x07\x1e\xc2\xf4\xb3\x07\x19\n\x0cjson_gateway\x12\tkey_value\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12Q\n\x05mysql\x18\xce\x02 \x01(\x0b\x32\x0f.v1.MysqlEngineB.\xf2\xf8\xb3\x07\x1f\xca\xf3\xb3\x07\x1a\xc2\xf4\xb3\x07\x15\n\x0cjson_gateway\x12\x05mysql\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12Z\n\x08postgres\x18\xcd\x02 \x01(\x0b\x32\x12.v1.PostgresEngineB1\xf2\xf8\xb3\x07\"\xca\xf3\xb3\x07\x1d\xc2\xf4\xb3\x07\x18\n\x0cjson_gateway\x12\x08postgres\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12]\n\tsqlserver\x18\xcf\x02 \x01(\x0b\x32\x13.v1.SqlserverEngineB2\xf2\xf8\xb3\x07#\xca\xf3\xb3\x07\x1e\xc2\xf4\xb3\x07\x19\n\x0cjson_gateway\x12\tsqlserver\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\x42z\n\rsecret_engine\x12i\xaa\xf8\xb3\x07\t\xaa\xf8\xb3\x07\x04name\xaa\xf8\xb3\x07\t\xaa\xf8\xb3\x07\x04tags\xaa\xf8\xb3\x07\x14\xaa\xf8\xb3\x07\x0fsecret_store_id\xaa\xf8\xb3\x07\x1b\xaa\xf8\xb3\x07\x16secret_store_root_path\xaa\xf8\xb3\x07\x0f\xaa\xf8\xb3\x07\npublic_key\"\xe1\x0c\n\x15\x41\x63tiveDirectoryEngine\x12\x64\n\x0e\x61\x66ter_read_ttl\x18\xf4\x07 \x01(\x0b\x32\x19.google.protobuf.DurationB0\xf2\xf8\xb3\x07+\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07!\xc2\xf4\xb3\x07\x1c\n\x0cjson_gateway\x12\x0c\x61\x66terReadTtl\x12?\n\x06\x62inddn\x18l \x01(\tB/\xf2\xf8\xb3\x07*\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1b\xc2\xf4\xb3\x07\x16\n\x0cjson_gateway\x12\x06\x62inddn\x12\x43\n\x08\x62indpass\x18m \x01(\tB1\xf2\xf8\xb3\x07,\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1d\xc2\xf4\xb3\x07\x18\n\x0cjson_gateway\x12\x08\x62indpass\x12\x44\n\x0b\x63\x65rtificate\x18k \x01(\tB/\xf2\xf8\xb3\x07*\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07 \xc2\xf4\xb3\x07\x1b\n\x0cjson_gateway\x12\x0b\x63\x65rtificate\x12Q\n\x12\x63onnection_timeout\x18g \x01(\rB5\xf2\xf8\xb3\x07\x30\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07&\xc2\xf4\xb3\x07!\n\x0cjson_gateway\x12\x11\x63onnectionTimeout\x12`\n\x1a\x64o_not_validate_timestamps\x18\xf7\x07 \x01(\x08\x42;\xf2\xf8\xb3\x07\x36\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07,\xc2\xf4\xb3\x07\'\n\x0cjson_gateway\x12\x17\x64oNotValidateTimestamps\x12\x45\n\x0cinsecure_tls\x18j \x01(\x08\x42/\xf2\xf8\xb3\x07*\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07 \xc2\xf4\xb3\x07\x1b\n\x0cjson_gateway\x12\x0binsecureTls\x12p\n\x14max_backoff_duration\x18\xf8\x07 \x01(\x0b\x32\x19.google.protobuf.DurationB6\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\'\xc2\xf4\xb3\x07\"\n\x0cjson_gateway\x12\x12maxBackoffDuration\x12S\n\x06policy\x18\xf6\x07 \x01(\x0b\x32\x16.v1.SecretEnginePolicyB*\xf2\xf8\xb3\x07%\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1b\xc2\xf4\xb3\x07\x16\n\x0cjson_gateway\x12\x06policy\x12K\n\x0frequest_timeout\x18h \x01(\rB2\xf2\xf8\xb3\x07-\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07#\xc2\xf4\xb3\x07\x1e\n\x0cjson_gateway\x12\x0erequestTimeout\x12?\n\tstart_tls\x18i \x01(\x08\x42,\xf2\xf8\xb3\x07\'\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1d\xc2\xf4\xb3\x07\x18\n\x0cjson_gateway\x12\x08startTls\x12P\n\x03ttl\x18\xf5\x07 \x01(\x0b\x32\x19.google.protobuf.DurationB\'\xf2\xf8\xb3\x07\"\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x18\xc2\xf4\xb3\x07\x13\n\x0cjson_gateway\x12\x03ttl\x12\x41\n\tupndomain\x18\xf3\x07 \x01(\tB-\xf2\xf8\xb3\x07(\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1e\xc2\xf4\xb3\x07\x19\n\x0cjson_gateway\x12\tupndomain\x12\x39\n\x03url\x18\x66 \x01(\tB,\xf2\xf8\xb3\x07\'\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x18\xc2\xf4\xb3\x07\x13\n\x0cjson_gateway\x12\x03url\x12;\n\x06userdn\x18\xf2\x07 \x01(\tB*\xf2\xf8\xb3\x07%\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1b\xc2\xf4\xb3\x07\x16\n\x0cjson_gateway\x12\x06userdn\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12!\n\x04type\x18\x03 \x01(\tB\x13\xf2\xf8\xb3\x07\x0e\xb0\xf3\xb3\x07\x01\xb2\xf4\xb3\x07\x04!cli\x12(\n\x0fsecret_store_id\x18\x05 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12/\n\x16secret_store_root_path\x18\x06 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\"\n\x04tags\x18\x07 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x32\n\npublic_key\x18\x08 \x01(\x0c\x42\x1e\xf2\xf8\xb3\x07\x19\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\xb2\xf4\xb3\x07\x01*\xb2\xf4\xb3\x07\x04!cli\x12.\n\x1akey_rotation_interval_days\x18\t \x01(\x05\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:{\xfa\xf8\xb3\x07v\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07l\xc2\xf4\xb3\x07\x17\n\x03\x63li\x12\x10\x61\x63tive_directory\xc2\xf4\xb3\x07 \n\x0cjson_gateway\x12\x10\x61\x63tive_directory\xc2\xf4\xb3\x07&\n\x12terraform-provider\x12\x10\x61\x63tive_directory\"\xb5\x03\n\x0eKeyValueEngine\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12!\n\x04type\x18\x03 \x01(\tB\x13\xf2\xf8\xb3\x07\x0e\xb0\xf3\xb3\x07\x01\xb2\xf4\xb3\x07\x04!cli\x12(\n\x0fsecret_store_id\x18\x05 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12/\n\x16secret_store_root_path\x18\x06 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\"\n\x04tags\x18\x07 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x32\n\npublic_key\x18\x08 \x01(\x0c\x42\x1e\xf2\xf8\xb3\x07\x19\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\xb2\xf4\xb3\x07\x01*\xb2\xf4\xb3\x07\x04!cli\x12.\n\x1akey_rotation_interval_days\x18\t \x01(\x05\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:f\xfa\xf8\xb3\x07\x61\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07W\xc2\xf4\xb3\x07\x10\n\x03\x63li\x12\tkey_value\xc2\xf4\xb3\x07\x19\n\x0cjson_gateway\x12\tkey_value\xc2\xf4\xb3\x07\x1f\n\x12terraform-provider\x12\tkey_value\"\x92\t\n\x0bMysqlEngine\x12\x63\n\x0e\x61\x66ter_read_ttl\x18i \x01(\x0b\x32\x19.google.protobuf.DurationB0\xf2\xf8\xb3\x07+\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07!\xc2\xf4\xb3\x07\x1c\n\x0cjson_gateway\x12\x0c\x61\x66terReadTtl\x12\x43\n\x08\x64\x61tabase\x18l \x01(\tB1\xf2\xf8\xb3\x07,\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1d\xc2\xf4\xb3\x07\x18\n\x0cjson_gateway\x12\x08\x64\x61tabase\x12\x43\n\x08hostname\x18\x65 \x01(\tB1\xf2\xf8\xb3\x07,\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1d\xc2\xf4\xb3\x07\x18\n\x0cjson_gateway\x12\x08hostname\x12\x43\n\x08password\x18g \x01(\tB1\xf2\xf8\xb3\x07,\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1d\xc2\xf4\xb3\x07\x18\n\x0cjson_gateway\x12\x08password\x12R\n\x06policy\x18k \x01(\x0b\x32\x16.v1.SecretEnginePolicyB*\xf2\xf8\xb3\x07%\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1b\xc2\xf4\xb3\x07\x16\n\x0cjson_gateway\x12\x06policy\x12;\n\x04port\x18h \x01(\rB-\xf2\xf8\xb3\x07(\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x19\xc2\xf4\xb3\x07\x14\n\x0cjson_gateway\x12\x04port\x12\x34\n\x03tls\x18m \x01(\x08\x42\'\xf2\xf8\xb3\x07\"\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x18\xc2\xf4\xb3\x07\x13\n\x0cjson_gateway\x12\x03tls\x12K\n\x0ftls_skip_verify\x18\xf2\x07 \x01(\x08\x42\x31\xf2\xf8\xb3\x07,\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\"\xc2\xf4\xb3\x07\x1d\n\x0cjson_gateway\x12\rtlsSkipVerify\x12O\n\x03ttl\x18j \x01(\x0b\x32\x19.google.protobuf.DurationB\'\xf2\xf8\xb3\x07\"\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x18\xc2\xf4\xb3\x07\x13\n\x0cjson_gateway\x12\x03ttl\x12\x43\n\x08username\x18\x66 \x01(\tB1\xf2\xf8\xb3\x07,\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1d\xc2\xf4\xb3\x07\x18\n\x0cjson_gateway\x12\x08username\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12!\n\x04type\x18\x03 \x01(\tB\x13\xf2\xf8\xb3\x07\x0e\xb0\xf3\xb3\x07\x01\xb2\xf4\xb3\x07\x04!cli\x12(\n\x0fsecret_store_id\x18\x05 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12/\n\x16secret_store_root_path\x18\x06 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\"\n\x04tags\x18\x07 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x32\n\npublic_key\x18\x08 \x01(\x0c\x42\x1e\xf2\xf8\xb3\x07\x19\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\xb2\xf4\xb3\x07\x01*\xb2\xf4\xb3\x07\x04!cli\x12.\n\x1akey_rotation_interval_days\x18\t \x01(\x05\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:h\xfa\xf8\xb3\x07\x63\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07Y\xc2\xf4\xb3\x07\x0c\n\x03\x63li\x12\x05mysql\xc2\xf4\xb3\x07\x15\n\x0cjson_gateway\x12\x05mysql\xc2\xf4\xb3\x07)\n\x12terraform-provider\x12\x13mysql_secret_engine\"\xd1\x08\n\x0ePostgresEngine\x12\x63\n\x0e\x61\x66ter_read_ttl\x18i \x01(\x0b\x32\x19.google.protobuf.DurationB0\xf2\xf8\xb3\x07+\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07!\xc2\xf4\xb3\x07\x1c\n\x0cjson_gateway\x12\x0c\x61\x66terReadTtl\x12\x43\n\x08\x64\x61tabase\x18l \x01(\tB1\xf2\xf8\xb3\x07,\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1d\xc2\xf4\xb3\x07\x18\n\x0cjson_gateway\x12\x08\x64\x61tabase\x12\x43\n\x08hostname\x18\x65 \x01(\tB1\xf2\xf8\xb3\x07,\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1d\xc2\xf4\xb3\x07\x18\n\x0cjson_gateway\x12\x08hostname\x12\x43\n\x08password\x18g \x01(\tB1\xf2\xf8\xb3\x07,\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1d\xc2\xf4\xb3\x07\x18\n\x0cjson_gateway\x12\x08password\x12R\n\x06policy\x18k \x01(\x0b\x32\x16.v1.SecretEnginePolicyB*\xf2\xf8\xb3\x07%\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1b\xc2\xf4\xb3\x07\x16\n\x0cjson_gateway\x12\x06policy\x12;\n\x04port\x18h \x01(\rB-\xf2\xf8\xb3\x07(\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x19\xc2\xf4\xb3\x07\x14\n\x0cjson_gateway\x12\x04port\x12\x34\n\x03tls\x18m \x01(\x08\x42\'\xf2\xf8\xb3\x07\"\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x18\xc2\xf4\xb3\x07\x13\n\x0cjson_gateway\x12\x03tls\x12O\n\x03ttl\x18j \x01(\x0b\x32\x19.google.protobuf.DurationB\'\xf2\xf8\xb3\x07\"\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x18\xc2\xf4\xb3\x07\x13\n\x0cjson_gateway\x12\x03ttl\x12\x43\n\x08username\x18\x66 \x01(\tB1\xf2\xf8\xb3\x07,\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1d\xc2\xf4\xb3\x07\x18\n\x0cjson_gateway\x12\x08username\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12!\n\x04type\x18\x03 \x01(\tB\x13\xf2\xf8\xb3\x07\x0e\xb0\xf3\xb3\x07\x01\xb2\xf4\xb3\x07\x04!cli\x12(\n\x0fsecret_store_id\x18\x05 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12/\n\x16secret_store_root_path\x18\x06 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\"\n\x04tags\x18\x07 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x32\n\npublic_key\x18\x08 \x01(\x0c\x42\x1e\xf2\xf8\xb3\x07\x19\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\xb2\xf4\xb3\x07\x01*\xb2\xf4\xb3\x07\x04!cli\x12.\n\x1akey_rotation_interval_days\x18\t \x01(\x05\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:q\xfa\xf8\xb3\x07l\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x62\xc2\xf4\xb3\x07\x0f\n\x03\x63li\x12\x08postgres\xc2\xf4\xb3\x07\x18\n\x0cjson_gateway\x12\x08postgres\xc2\xf4\xb3\x07,\n\x12terraform-provider\x12\x16postgres_secret_engine\"\xa2\t\n\x0fSqlserverEngine\x12\x63\n\x0e\x61\x66ter_read_ttl\x18i \x01(\x0b\x32\x19.google.protobuf.DurationB0\xf2\xf8\xb3\x07+\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07!\xc2\xf4\xb3\x07\x1c\n\x0cjson_gateway\x12\x0c\x61\x66terReadTtl\x12\x43\n\x08\x64\x61tabase\x18l \x01(\tB1\xf2\xf8\xb3\x07,\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1d\xc2\xf4\xb3\x07\x18\n\x0cjson_gateway\x12\x08\x64\x61tabase\x12\x43\n\x08hostname\x18\x65 \x01(\tB1\xf2\xf8\xb3\x07,\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1d\xc2\xf4\xb3\x07\x18\n\x0cjson_gateway\x12\x08hostname\x12\x43\n\x08password\x18g \x01(\tB1\xf2\xf8\xb3\x07,\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1d\xc2\xf4\xb3\x07\x18\n\x0cjson_gateway\x12\x08password\x12R\n\x06policy\x18k \x01(\x0b\x32\x16.v1.SecretEnginePolicyB*\xf2\xf8\xb3\x07%\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1b\xc2\xf4\xb3\x07\x16\n\x0cjson_gateway\x12\x06policy\x12;\n\x04port\x18h \x01(\rB-\xf2\xf8\xb3\x07(\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x19\xc2\xf4\xb3\x07\x14\n\x0cjson_gateway\x12\x04port\x12\x34\n\x03tls\x18m \x01(\x08\x42\'\xf2\xf8\xb3\x07\"\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x18\xc2\xf4\xb3\x07\x13\n\x0cjson_gateway\x12\x03tls\x12K\n\x0ftls_skip_verify\x18\xf2\x07 \x01(\x08\x42\x31\xf2\xf8\xb3\x07,\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\"\xc2\xf4\xb3\x07\x1d\n\x0cjson_gateway\x12\rtlsSkipVerify\x12O\n\x03ttl\x18j \x01(\x0b\x32\x19.google.protobuf.DurationB\'\xf2\xf8\xb3\x07\"\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x18\xc2\xf4\xb3\x07\x13\n\x0cjson_gateway\x12\x03ttl\x12\x43\n\x08username\x18\x66 \x01(\tB1\xf2\xf8\xb3\x07,\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1d\xc2\xf4\xb3\x07\x18\n\x0cjson_gateway\x12\x08username\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12!\n\x04type\x18\x03 \x01(\tB\x13\xf2\xf8\xb3\x07\x0e\xb0\xf3\xb3\x07\x01\xb2\xf4\xb3\x07\x04!cli\x12(\n\x0fsecret_store_id\x18\x05 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12/\n\x16secret_store_root_path\x18\x06 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\"\n\x04tags\x18\x07 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x32\n\npublic_key\x18\x08 \x01(\x0c\x42\x1e\xf2\xf8\xb3\x07\x19\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\xb2\xf4\xb3\x07\x01*\xb2\xf4\xb3\x07\x04!cli\x12.\n\x1akey_rotation_interval_days\x18\t \x01(\x05\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:t\xfa\xf8\xb3\x07o\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x65\xc2\xf4\xb3\x07\x10\n\x03\x63li\x12\tsqlserver\xc2\xf4\xb3\x07\x19\n\x0cjson_gateway\x12\tsqlserver\xc2\xf4\xb3\x07-\n\x12terraform-provider\x12\x17sqlserver_secret_engineBm\n\x19\x63om.strongdm.api.plumbingB\x19SecretEngineTypesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_SECRETENGINE = DESCRIPTOR.message_types_by_name['SecretEngine']
_ACTIVEDIRECTORYENGINE = DESCRIPTOR.message_types_by_name['ActiveDirectoryEngine']
_KEYVALUEENGINE = DESCRIPTOR.message_types_by_name['KeyValueEngine']
_MYSQLENGINE = DESCRIPTOR.message_types_by_name['MysqlEngine']
_POSTGRESENGINE = DESCRIPTOR.message_types_by_name['PostgresEngine']
_SQLSERVERENGINE = DESCRIPTOR.message_types_by_name['SqlserverEngine']
SecretEngine = _reflection.GeneratedProtocolMessageType('SecretEngine', (_message.Message,), {
  'DESCRIPTOR' : _SECRETENGINE,
  '__module__' : 'secret_engine_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretEngine)
  })
_sym_db.RegisterMessage(SecretEngine)

ActiveDirectoryEngine = _reflection.GeneratedProtocolMessageType('ActiveDirectoryEngine', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVEDIRECTORYENGINE,
  '__module__' : 'secret_engine_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.ActiveDirectoryEngine)
  })
_sym_db.RegisterMessage(ActiveDirectoryEngine)

KeyValueEngine = _reflection.GeneratedProtocolMessageType('KeyValueEngine', (_message.Message,), {
  'DESCRIPTOR' : _KEYVALUEENGINE,
  '__module__' : 'secret_engine_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.KeyValueEngine)
  })
_sym_db.RegisterMessage(KeyValueEngine)

MysqlEngine = _reflection.GeneratedProtocolMessageType('MysqlEngine', (_message.Message,), {
  'DESCRIPTOR' : _MYSQLENGINE,
  '__module__' : 'secret_engine_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.MysqlEngine)
  })
_sym_db.RegisterMessage(MysqlEngine)

PostgresEngine = _reflection.GeneratedProtocolMessageType('PostgresEngine', (_message.Message,), {
  'DESCRIPTOR' : _POSTGRESENGINE,
  '__module__' : 'secret_engine_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.PostgresEngine)
  })
_sym_db.RegisterMessage(PostgresEngine)

SqlserverEngine = _reflection.GeneratedProtocolMessageType('SqlserverEngine', (_message.Message,), {
  'DESCRIPTOR' : _SQLSERVERENGINE,
  '__module__' : 'secret_engine_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.SqlserverEngine)
  })
_sym_db.RegisterMessage(SqlserverEngine)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\031SecretEngineTypesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _SECRETENGINE.oneofs_by_name['secret_engine']._options = None
  _SECRETENGINE.oneofs_by_name['secret_engine']._serialized_options = b'\252\370\263\007\t\252\370\263\007\004name\252\370\263\007\t\252\370\263\007\004tags\252\370\263\007\024\252\370\263\007\017secret_store_id\252\370\263\007\033\252\370\263\007\026secret_store_root_path\252\370\263\007\017\252\370\263\007\npublic_key'
  _SECRETENGINE.fields_by_name['active_directory']._options = None
  _SECRETENGINE.fields_by_name['active_directory']._serialized_options = b'\362\370\263\007*\312\363\263\007%\302\364\263\007 \n\014json_gateway\022\020active_directory\362\370\263\007\005\260\363\263\007\001'
  _SECRETENGINE.fields_by_name['key_value']._options = None
  _SECRETENGINE.fields_by_name['key_value']._serialized_options = b'\362\370\263\007#\312\363\263\007\036\302\364\263\007\031\n\014json_gateway\022\tkey_value\362\370\263\007\005\260\363\263\007\001'
  _SECRETENGINE.fields_by_name['mysql']._options = None
  _SECRETENGINE.fields_by_name['mysql']._serialized_options = b'\362\370\263\007\037\312\363\263\007\032\302\364\263\007\025\n\014json_gateway\022\005mysql\362\370\263\007\005\260\363\263\007\001'
  _SECRETENGINE.fields_by_name['postgres']._options = None
  _SECRETENGINE.fields_by_name['postgres']._serialized_options = b'\362\370\263\007\"\312\363\263\007\035\302\364\263\007\030\n\014json_gateway\022\010postgres\362\370\263\007\005\260\363\263\007\001'
  _SECRETENGINE.fields_by_name['sqlserver']._options = None
  _SECRETENGINE.fields_by_name['sqlserver']._serialized_options = b'\362\370\263\007#\312\363\263\007\036\302\364\263\007\031\n\014json_gateway\022\tsqlserver\362\370\263\007\005\260\363\263\007\001'
  _SECRETENGINE._options = None
  _SECRETENGINE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _ACTIVEDIRECTORYENGINE.fields_by_name['after_read_ttl']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['after_read_ttl']._serialized_options = b'\362\370\263\007+\260\363\263\007\001\312\363\263\007!\302\364\263\007\034\n\014json_gateway\022\014afterReadTtl'
  _ACTIVEDIRECTORYENGINE.fields_by_name['binddn']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['binddn']._serialized_options = b'\362\370\263\007*\260\363\263\007\001\300\363\263\007\001\312\363\263\007\033\302\364\263\007\026\n\014json_gateway\022\006binddn'
  _ACTIVEDIRECTORYENGINE.fields_by_name['bindpass']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['bindpass']._serialized_options = b'\362\370\263\007,\260\363\263\007\001\300\363\263\007\001\312\363\263\007\035\302\364\263\007\030\n\014json_gateway\022\010bindpass'
  _ACTIVEDIRECTORYENGINE.fields_by_name['certificate']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['certificate']._serialized_options = b'\362\370\263\007*\260\363\263\007\001\312\363\263\007 \302\364\263\007\033\n\014json_gateway\022\013certificate'
  _ACTIVEDIRECTORYENGINE.fields_by_name['connection_timeout']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['connection_timeout']._serialized_options = b'\362\370\263\0070\260\363\263\007\001\312\363\263\007&\302\364\263\007!\n\014json_gateway\022\021connectionTimeout'
  _ACTIVEDIRECTORYENGINE.fields_by_name['do_not_validate_timestamps']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['do_not_validate_timestamps']._serialized_options = b'\362\370\263\0076\260\363\263\007\001\312\363\263\007,\302\364\263\007\'\n\014json_gateway\022\027doNotValidateTimestamps'
  _ACTIVEDIRECTORYENGINE.fields_by_name['insecure_tls']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['insecure_tls']._serialized_options = b'\362\370\263\007*\260\363\263\007\001\312\363\263\007 \302\364\263\007\033\n\014json_gateway\022\013insecureTls'
  _ACTIVEDIRECTORYENGINE.fields_by_name['max_backoff_duration']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['max_backoff_duration']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\312\363\263\007\'\302\364\263\007\"\n\014json_gateway\022\022maxBackoffDuration'
  _ACTIVEDIRECTORYENGINE.fields_by_name['policy']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['policy']._serialized_options = b'\362\370\263\007%\260\363\263\007\001\312\363\263\007\033\302\364\263\007\026\n\014json_gateway\022\006policy'
  _ACTIVEDIRECTORYENGINE.fields_by_name['request_timeout']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['request_timeout']._serialized_options = b'\362\370\263\007-\260\363\263\007\001\312\363\263\007#\302\364\263\007\036\n\014json_gateway\022\016requestTimeout'
  _ACTIVEDIRECTORYENGINE.fields_by_name['start_tls']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['start_tls']._serialized_options = b'\362\370\263\007\'\260\363\263\007\001\312\363\263\007\035\302\364\263\007\030\n\014json_gateway\022\010startTls'
  _ACTIVEDIRECTORYENGINE.fields_by_name['ttl']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['ttl']._serialized_options = b'\362\370\263\007\"\260\363\263\007\001\312\363\263\007\030\302\364\263\007\023\n\014json_gateway\022\003ttl'
  _ACTIVEDIRECTORYENGINE.fields_by_name['upndomain']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['upndomain']._serialized_options = b'\362\370\263\007(\260\363\263\007\001\312\363\263\007\036\302\364\263\007\031\n\014json_gateway\022\tupndomain'
  _ACTIVEDIRECTORYENGINE.fields_by_name['url']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['url']._serialized_options = b'\362\370\263\007\'\260\363\263\007\001\300\363\263\007\001\312\363\263\007\030\302\364\263\007\023\n\014json_gateway\022\003url'
  _ACTIVEDIRECTORYENGINE.fields_by_name['userdn']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['userdn']._serialized_options = b'\362\370\263\007%\260\363\263\007\001\312\363\263\007\033\302\364\263\007\026\n\014json_gateway\022\006userdn'
  _ACTIVEDIRECTORYENGINE.fields_by_name['id']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACTIVEDIRECTORYENGINE.fields_by_name['name']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _ACTIVEDIRECTORYENGINE.fields_by_name['type']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['type']._serialized_options = b'\362\370\263\007\016\260\363\263\007\001\262\364\263\007\004!cli'
  _ACTIVEDIRECTORYENGINE.fields_by_name['secret_store_id']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['secret_store_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _ACTIVEDIRECTORYENGINE.fields_by_name['secret_store_root_path']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['secret_store_root_path']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _ACTIVEDIRECTORYENGINE.fields_by_name['tags']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACTIVEDIRECTORYENGINE.fields_by_name['public_key']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['public_key']._serialized_options = b'\362\370\263\007\031\260\363\263\007\001\230\364\263\007\001\262\364\263\007\001*\262\364\263\007\004!cli'
  _ACTIVEDIRECTORYENGINE.fields_by_name['key_rotation_interval_days']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['key_rotation_interval_days']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACTIVEDIRECTORYENGINE._options = None
  _ACTIVEDIRECTORYENGINE._serialized_options = b'\372\370\263\007v\250\363\263\007\001\312\363\263\007l\302\364\263\007\027\n\003cli\022\020active_directory\302\364\263\007 \n\014json_gateway\022\020active_directory\302\364\263\007&\n\022terraform-provider\022\020active_directory'
  _KEYVALUEENGINE.fields_by_name['id']._options = None
  _KEYVALUEENGINE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _KEYVALUEENGINE.fields_by_name['name']._options = None
  _KEYVALUEENGINE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _KEYVALUEENGINE.fields_by_name['type']._options = None
  _KEYVALUEENGINE.fields_by_name['type']._serialized_options = b'\362\370\263\007\016\260\363\263\007\001\262\364\263\007\004!cli'
  _KEYVALUEENGINE.fields_by_name['secret_store_id']._options = None
  _KEYVALUEENGINE.fields_by_name['secret_store_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _KEYVALUEENGINE.fields_by_name['secret_store_root_path']._options = None
  _KEYVALUEENGINE.fields_by_name['secret_store_root_path']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _KEYVALUEENGINE.fields_by_name['tags']._options = None
  _KEYVALUEENGINE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _KEYVALUEENGINE.fields_by_name['public_key']._options = None
  _KEYVALUEENGINE.fields_by_name['public_key']._serialized_options = b'\362\370\263\007\031\260\363\263\007\001\230\364\263\007\001\262\364\263\007\001*\262\364\263\007\004!cli'
  _KEYVALUEENGINE.fields_by_name['key_rotation_interval_days']._options = None
  _KEYVALUEENGINE.fields_by_name['key_rotation_interval_days']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _KEYVALUEENGINE._options = None
  _KEYVALUEENGINE._serialized_options = b'\372\370\263\007a\250\363\263\007\001\312\363\263\007W\302\364\263\007\020\n\003cli\022\tkey_value\302\364\263\007\031\n\014json_gateway\022\tkey_value\302\364\263\007\037\n\022terraform-provider\022\tkey_value'
  _MYSQLENGINE.fields_by_name['after_read_ttl']._options = None
  _MYSQLENGINE.fields_by_name['after_read_ttl']._serialized_options = b'\362\370\263\007+\260\363\263\007\001\312\363\263\007!\302\364\263\007\034\n\014json_gateway\022\014afterReadTtl'
  _MYSQLENGINE.fields_by_name['database']._options = None
  _MYSQLENGINE.fields_by_name['database']._serialized_options = b'\362\370\263\007,\260\363\263\007\001\300\363\263\007\001\312\363\263\007\035\302\364\263\007\030\n\014json_gateway\022\010database'
  _MYSQLENGINE.fields_by_name['hostname']._options = None
  _MYSQLENGINE.fields_by_name['hostname']._serialized_options = b'\362\370\263\007,\260\363\263\007\001\300\363\263\007\001\312\363\263\007\035\302\364\263\007\030\n\014json_gateway\022\010hostname'
  _MYSQLENGINE.fields_by_name['password']._options = None
  _MYSQLENGINE.fields_by_name['password']._serialized_options = b'\362\370\263\007,\260\363\263\007\001\300\363\263\007\001\312\363\263\007\035\302\364\263\007\030\n\014json_gateway\022\010password'
  _MYSQLENGINE.fields_by_name['policy']._options = None
  _MYSQLENGINE.fields_by_name['policy']._serialized_options = b'\362\370\263\007%\260\363\263\007\001\312\363\263\007\033\302\364\263\007\026\n\014json_gateway\022\006policy'
  _MYSQLENGINE.fields_by_name['port']._options = None
  _MYSQLENGINE.fields_by_name['port']._serialized_options = b'\362\370\263\007(\260\363\263\007\001\300\363\263\007\001\312\363\263\007\031\302\364\263\007\024\n\014json_gateway\022\004port'
  _MYSQLENGINE.fields_by_name['tls']._options = None
  _MYSQLENGINE.fields_by_name['tls']._serialized_options = b'\362\370\263\007\"\260\363\263\007\001\312\363\263\007\030\302\364\263\007\023\n\014json_gateway\022\003tls'
  _MYSQLENGINE.fields_by_name['tls_skip_verify']._options = None
  _MYSQLENGINE.fields_by_name['tls_skip_verify']._serialized_options = b'\362\370\263\007,\260\363\263\007\001\312\363\263\007\"\302\364\263\007\035\n\014json_gateway\022\rtlsSkipVerify'
  _MYSQLENGINE.fields_by_name['ttl']._options = None
  _MYSQLENGINE.fields_by_name['ttl']._serialized_options = b'\362\370\263\007\"\260\363\263\007\001\312\363\263\007\030\302\364\263\007\023\n\014json_gateway\022\003ttl'
  _MYSQLENGINE.fields_by_name['username']._options = None
  _MYSQLENGINE.fields_by_name['username']._serialized_options = b'\362\370\263\007,\260\363\263\007\001\300\363\263\007\001\312\363\263\007\035\302\364\263\007\030\n\014json_gateway\022\010username'
  _MYSQLENGINE.fields_by_name['id']._options = None
  _MYSQLENGINE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MYSQLENGINE.fields_by_name['name']._options = None
  _MYSQLENGINE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _MYSQLENGINE.fields_by_name['type']._options = None
  _MYSQLENGINE.fields_by_name['type']._serialized_options = b'\362\370\263\007\016\260\363\263\007\001\262\364\263\007\004!cli'
  _MYSQLENGINE.fields_by_name['secret_store_id']._options = None
  _MYSQLENGINE.fields_by_name['secret_store_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _MYSQLENGINE.fields_by_name['secret_store_root_path']._options = None
  _MYSQLENGINE.fields_by_name['secret_store_root_path']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _MYSQLENGINE.fields_by_name['tags']._options = None
  _MYSQLENGINE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MYSQLENGINE.fields_by_name['public_key']._options = None
  _MYSQLENGINE.fields_by_name['public_key']._serialized_options = b'\362\370\263\007\031\260\363\263\007\001\230\364\263\007\001\262\364\263\007\001*\262\364\263\007\004!cli'
  _MYSQLENGINE.fields_by_name['key_rotation_interval_days']._options = None
  _MYSQLENGINE.fields_by_name['key_rotation_interval_days']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MYSQLENGINE._options = None
  _MYSQLENGINE._serialized_options = b'\372\370\263\007c\250\363\263\007\001\312\363\263\007Y\302\364\263\007\014\n\003cli\022\005mysql\302\364\263\007\025\n\014json_gateway\022\005mysql\302\364\263\007)\n\022terraform-provider\022\023mysql_secret_engine'
  _POSTGRESENGINE.fields_by_name['after_read_ttl']._options = None
  _POSTGRESENGINE.fields_by_name['after_read_ttl']._serialized_options = b'\362\370\263\007+\260\363\263\007\001\312\363\263\007!\302\364\263\007\034\n\014json_gateway\022\014afterReadTtl'
  _POSTGRESENGINE.fields_by_name['database']._options = None
  _POSTGRESENGINE.fields_by_name['database']._serialized_options = b'\362\370\263\007,\260\363\263\007\001\300\363\263\007\001\312\363\263\007\035\302\364\263\007\030\n\014json_gateway\022\010database'
  _POSTGRESENGINE.fields_by_name['hostname']._options = None
  _POSTGRESENGINE.fields_by_name['hostname']._serialized_options = b'\362\370\263\007,\260\363\263\007\001\300\363\263\007\001\312\363\263\007\035\302\364\263\007\030\n\014json_gateway\022\010hostname'
  _POSTGRESENGINE.fields_by_name['password']._options = None
  _POSTGRESENGINE.fields_by_name['password']._serialized_options = b'\362\370\263\007,\260\363\263\007\001\300\363\263\007\001\312\363\263\007\035\302\364\263\007\030\n\014json_gateway\022\010password'
  _POSTGRESENGINE.fields_by_name['policy']._options = None
  _POSTGRESENGINE.fields_by_name['policy']._serialized_options = b'\362\370\263\007%\260\363\263\007\001\312\363\263\007\033\302\364\263\007\026\n\014json_gateway\022\006policy'
  _POSTGRESENGINE.fields_by_name['port']._options = None
  _POSTGRESENGINE.fields_by_name['port']._serialized_options = b'\362\370\263\007(\260\363\263\007\001\300\363\263\007\001\312\363\263\007\031\302\364\263\007\024\n\014json_gateway\022\004port'
  _POSTGRESENGINE.fields_by_name['tls']._options = None
  _POSTGRESENGINE.fields_by_name['tls']._serialized_options = b'\362\370\263\007\"\260\363\263\007\001\312\363\263\007\030\302\364\263\007\023\n\014json_gateway\022\003tls'
  _POSTGRESENGINE.fields_by_name['ttl']._options = None
  _POSTGRESENGINE.fields_by_name['ttl']._serialized_options = b'\362\370\263\007\"\260\363\263\007\001\312\363\263\007\030\302\364\263\007\023\n\014json_gateway\022\003ttl'
  _POSTGRESENGINE.fields_by_name['username']._options = None
  _POSTGRESENGINE.fields_by_name['username']._serialized_options = b'\362\370\263\007,\260\363\263\007\001\300\363\263\007\001\312\363\263\007\035\302\364\263\007\030\n\014json_gateway\022\010username'
  _POSTGRESENGINE.fields_by_name['id']._options = None
  _POSTGRESENGINE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _POSTGRESENGINE.fields_by_name['name']._options = None
  _POSTGRESENGINE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _POSTGRESENGINE.fields_by_name['type']._options = None
  _POSTGRESENGINE.fields_by_name['type']._serialized_options = b'\362\370\263\007\016\260\363\263\007\001\262\364\263\007\004!cli'
  _POSTGRESENGINE.fields_by_name['secret_store_id']._options = None
  _POSTGRESENGINE.fields_by_name['secret_store_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _POSTGRESENGINE.fields_by_name['secret_store_root_path']._options = None
  _POSTGRESENGINE.fields_by_name['secret_store_root_path']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _POSTGRESENGINE.fields_by_name['tags']._options = None
  _POSTGRESENGINE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _POSTGRESENGINE.fields_by_name['public_key']._options = None
  _POSTGRESENGINE.fields_by_name['public_key']._serialized_options = b'\362\370\263\007\031\260\363\263\007\001\230\364\263\007\001\262\364\263\007\001*\262\364\263\007\004!cli'
  _POSTGRESENGINE.fields_by_name['key_rotation_interval_days']._options = None
  _POSTGRESENGINE.fields_by_name['key_rotation_interval_days']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _POSTGRESENGINE._options = None
  _POSTGRESENGINE._serialized_options = b'\372\370\263\007l\250\363\263\007\001\312\363\263\007b\302\364\263\007\017\n\003cli\022\010postgres\302\364\263\007\030\n\014json_gateway\022\010postgres\302\364\263\007,\n\022terraform-provider\022\026postgres_secret_engine'
  _SQLSERVERENGINE.fields_by_name['after_read_ttl']._options = None
  _SQLSERVERENGINE.fields_by_name['after_read_ttl']._serialized_options = b'\362\370\263\007+\260\363\263\007\001\312\363\263\007!\302\364\263\007\034\n\014json_gateway\022\014afterReadTtl'
  _SQLSERVERENGINE.fields_by_name['database']._options = None
  _SQLSERVERENGINE.fields_by_name['database']._serialized_options = b'\362\370\263\007,\260\363\263\007\001\300\363\263\007\001\312\363\263\007\035\302\364\263\007\030\n\014json_gateway\022\010database'
  _SQLSERVERENGINE.fields_by_name['hostname']._options = None
  _SQLSERVERENGINE.fields_by_name['hostname']._serialized_options = b'\362\370\263\007,\260\363\263\007\001\300\363\263\007\001\312\363\263\007\035\302\364\263\007\030\n\014json_gateway\022\010hostname'
  _SQLSERVERENGINE.fields_by_name['password']._options = None
  _SQLSERVERENGINE.fields_by_name['password']._serialized_options = b'\362\370\263\007,\260\363\263\007\001\300\363\263\007\001\312\363\263\007\035\302\364\263\007\030\n\014json_gateway\022\010password'
  _SQLSERVERENGINE.fields_by_name['policy']._options = None
  _SQLSERVERENGINE.fields_by_name['policy']._serialized_options = b'\362\370\263\007%\260\363\263\007\001\312\363\263\007\033\302\364\263\007\026\n\014json_gateway\022\006policy'
  _SQLSERVERENGINE.fields_by_name['port']._options = None
  _SQLSERVERENGINE.fields_by_name['port']._serialized_options = b'\362\370\263\007(\260\363\263\007\001\300\363\263\007\001\312\363\263\007\031\302\364\263\007\024\n\014json_gateway\022\004port'
  _SQLSERVERENGINE.fields_by_name['tls']._options = None
  _SQLSERVERENGINE.fields_by_name['tls']._serialized_options = b'\362\370\263\007\"\260\363\263\007\001\312\363\263\007\030\302\364\263\007\023\n\014json_gateway\022\003tls'
  _SQLSERVERENGINE.fields_by_name['tls_skip_verify']._options = None
  _SQLSERVERENGINE.fields_by_name['tls_skip_verify']._serialized_options = b'\362\370\263\007,\260\363\263\007\001\312\363\263\007\"\302\364\263\007\035\n\014json_gateway\022\rtlsSkipVerify'
  _SQLSERVERENGINE.fields_by_name['ttl']._options = None
  _SQLSERVERENGINE.fields_by_name['ttl']._serialized_options = b'\362\370\263\007\"\260\363\263\007\001\312\363\263\007\030\302\364\263\007\023\n\014json_gateway\022\003ttl'
  _SQLSERVERENGINE.fields_by_name['username']._options = None
  _SQLSERVERENGINE.fields_by_name['username']._serialized_options = b'\362\370\263\007,\260\363\263\007\001\300\363\263\007\001\312\363\263\007\035\302\364\263\007\030\n\014json_gateway\022\010username'
  _SQLSERVERENGINE.fields_by_name['id']._options = None
  _SQLSERVERENGINE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SQLSERVERENGINE.fields_by_name['name']._options = None
  _SQLSERVERENGINE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _SQLSERVERENGINE.fields_by_name['type']._options = None
  _SQLSERVERENGINE.fields_by_name['type']._serialized_options = b'\362\370\263\007\016\260\363\263\007\001\262\364\263\007\004!cli'
  _SQLSERVERENGINE.fields_by_name['secret_store_id']._options = None
  _SQLSERVERENGINE.fields_by_name['secret_store_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _SQLSERVERENGINE.fields_by_name['secret_store_root_path']._options = None
  _SQLSERVERENGINE.fields_by_name['secret_store_root_path']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _SQLSERVERENGINE.fields_by_name['tags']._options = None
  _SQLSERVERENGINE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SQLSERVERENGINE.fields_by_name['public_key']._options = None
  _SQLSERVERENGINE.fields_by_name['public_key']._serialized_options = b'\362\370\263\007\031\260\363\263\007\001\230\364\263\007\001\262\364\263\007\001*\262\364\263\007\004!cli'
  _SQLSERVERENGINE.fields_by_name['key_rotation_interval_days']._options = None
  _SQLSERVERENGINE.fields_by_name['key_rotation_interval_days']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SQLSERVERENGINE._options = None
  _SQLSERVERENGINE._serialized_options = b'\372\370\263\007o\250\363\263\007\001\312\363\263\007e\302\364\263\007\020\n\003cli\022\tsqlserver\302\364\263\007\031\n\014json_gateway\022\tsqlserver\302\364\263\007-\n\022terraform-provider\022\027sqlserver_secret_engine'
  _SECRETENGINE._serialized_start=121
  _SECRETENGINE._serialized_end=750
  _ACTIVEDIRECTORYENGINE._serialized_start=753
  _ACTIVEDIRECTORYENGINE._serialized_end=2386
  _KEYVALUEENGINE._serialized_start=2389
  _KEYVALUEENGINE._serialized_end=2826
  _MYSQLENGINE._serialized_start=2829
  _MYSQLENGINE._serialized_end=3999
  _POSTGRESENGINE._serialized_start=4002
  _POSTGRESENGINE._serialized_end=5107
  _SQLSERVERENGINE._serialized_start=5110
  _SQLSERVERENGINE._serialized_end=6296
# @@protoc_insertion_point(module_scope)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: secret_store_healths.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1asecret_store_healths.proto\x12\x02v1\x1a\roptions.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\nspec.proto\"\x8b\x01\n\x1cSecretStoreHealthListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:(\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\x95\x02\n\x1dSecretStoreHealthListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12?\n\x14secret_store_healths\x18\x02 \x03(\x0b\x32\x15.v1.SecretStoreHealthB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:2\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x83\x01\n\x1dSecretStoreHealthCheckRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12#\n\x0fsecret_store_id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x14\xfa\xf8\xb3\x07\x0f\xd2\xf3\xb3\x07\ngo_private\"\x97\x01\n\x1dSecretStoreHealthcheckRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12#\n\x0fsecret_store_id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:(\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\xc3\x01\n\x1eSecretStoreHealthCheckResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadata\x12W\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\x1e\xfa\xf8\xb3\x07\x0f\xd2\xf3\xb3\x07\ngo_private\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xd7\x01\n\x1eSecretStoreHealthcheckResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadata\x12W\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:2\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xfb\x02\n\x11SecretStoreHealth\x12#\n\x0fsecret_store_id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1b\n\x07node_id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1a\n\x06status\x18\x04 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12:\n\nchanged_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12:\n\nchecked_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x19\n\x05\x65rror\x18\x08 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12 \n\x0creachability\x18\t \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x19\n\x05\x66lags\x18\n \x03(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:2\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01J\x04\x08\x03\x10\x04\x32\x8d\x04\n\x12SecretStoreHealths\x12|\n\x04List\x12 .v1.SecretStoreHealthListRequest\x1a!.v1.SecretStoreHealthListResponse\"/\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x1d\xaa\xf3\xb3\x07\x18/v1/secret-store-healths\x12\x94\x01\n\x05\x43heck\x12!.v1.SecretStoreHealthCheckRequest\x1a\".v1.SecretStoreHealthCheckResponse\"D\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x1d\xaa\xf3\xb3\x07\x18/v1/secret-store-healths\x82\xf9\xb3\x07\x0f\xca\xf9\xb3\x07\ngo_private\x12\x86\x01\n\x0bHealthcheck\x12!.v1.SecretStoreHealthcheckRequest\x1a\".v1.SecretStoreHealthcheckResponse\"0\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x1d\xaa\xf3\xb3\x07\x18/v1/secret-store-healths\x1aY\xca\xf9\xb3\x07\x16\xc2\xf9\xb3\x07\x11SecretStoreHealth\xca\xf9\xb3\x07\x07\xd2\xf9\xb3\x07\x02x-\xca\xf9\xb3\x07\x05\xd8\xf9\xb3\x07\x01\xca\xf9\xb3\x07\x06\xca\xf9\xb3\x07\x01*\xca\xf9\xb3\x07\x18\xca\xf9\xb3\x07\x13!terraform-providerB\x96\x01\n\x19\x63om.strongdm.api.plumbingB\x1aSecretStoreHealthsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\xc2\x92\xb4\x07\x06\xa2\x8c\xb4\x07\x01*\xc2\x92\xb4\x07\x18\xa2\x8c\xb4\x07\x13!terraform-providerb\x06proto3')



_SECRETSTOREHEALTHLISTREQUEST = DESCRIPTOR.message_types_by_name['SecretStoreHealthListRequest']
_SECRETSTOREHEALTHLISTRESPONSE = DESCRIPTOR.message_types_by_name['SecretStoreHealthListResponse']
_SECRETSTOREHEALTHCHECKREQUEST = DESCRIPTOR.message_types_by_name['SecretStoreHealthCheckRequest']
_SECRETSTOREHEALTHCHECKREQUEST = DESCRIPTOR.message_types_by_name['SecretStoreHealthcheckRequest']
_SECRETSTOREHEALTHCHECKRESPONSE = DESCRIPTOR.message_types_by_name['SecretStoreHealthCheckResponse']
_SECRETSTOREHEALTHCHECKRESPONSE = DESCRIPTOR.message_types_by_name['SecretStoreHealthcheckResponse']
_SECRETSTOREHEALTH = DESCRIPTOR.message_types_by_name['SecretStoreHealth']
SecretStoreHealthListRequest = _reflection.GeneratedProtocolMessageType('SecretStoreHealthListRequest', (_message.Message,), {
  'DESCRIPTOR' : _SECRETSTOREHEALTHLISTREQUEST,
  '__module__' : 'secret_store_healths_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretStoreHealthListRequest)
  })
_sym_db.RegisterMessage(SecretStoreHealthListRequest)

SecretStoreHealthListResponse = _reflection.GeneratedProtocolMessageType('SecretStoreHealthListResponse', (_message.Message,), {
  'DESCRIPTOR' : _SECRETSTOREHEALTHLISTRESPONSE,
  '__module__' : 'secret_store_healths_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretStoreHealthListResponse)
  })
_sym_db.RegisterMessage(SecretStoreHealthListResponse)

SecretStoreHealthCheckRequest = _reflection.GeneratedProtocolMessageType('SecretStoreHealthCheckRequest', (_message.Message,), {
  'DESCRIPTOR' : _SECRETSTOREHEALTHCHECKREQUEST,
  '__module__' : 'secret_store_healths_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretStoreHealthCheckRequest)
  })
_sym_db.RegisterMessage(SecretStoreHealthCheckRequest)

SecretStoreHealthcheckRequest = _reflection.GeneratedProtocolMessageType('SecretStoreHealthcheckRequest', (_message.Message,), {
  'DESCRIPTOR' : _SECRETSTOREHEALTHCHECKREQUEST,
  '__module__' : 'secret_store_healths_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretStoreHealthcheckRequest)
  })
_sym_db.RegisterMessage(SecretStoreHealthcheckRequest)

SecretStoreHealthCheckResponse = _reflection.GeneratedProtocolMessageType('SecretStoreHealthCheckResponse', (_message.Message,), {
  'DESCRIPTOR' : _SECRETSTOREHEALTHCHECKRESPONSE,
  '__module__' : 'secret_store_healths_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretStoreHealthCheckResponse)
  })
_sym_db.RegisterMessage(SecretStoreHealthCheckResponse)

SecretStoreHealthcheckResponse = _reflection.GeneratedProtocolMessageType('SecretStoreHealthcheckResponse', (_message.Message,), {
  'DESCRIPTOR' : _SECRETSTOREHEALTHCHECKRESPONSE,
  '__module__' : 'secret_store_healths_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretStoreHealthcheckResponse)
  })
_sym_db.RegisterMessage(SecretStoreHealthcheckResponse)

SecretStoreHealth = _reflection.GeneratedProtocolMessageType('SecretStoreHealth', (_message.Message,), {
  'DESCRIPTOR' : _SECRETSTOREHEALTH,
  '__module__' : 'secret_store_healths_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretStoreHealth)
  })
_sym_db.RegisterMessage(SecretStoreHealth)

_SECRETSTOREHEALTHS = DESCRIPTOR.services_by_name['SecretStoreHealths']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\032SecretStoreHealthsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\302\222\264\007\006\242\214\264\007\001*\302\222\264\007\030\242\214\264\007\023!terraform-provider'
  _SECRETSTOREHEALTHLISTREQUEST.fields_by_name['filter']._options = None
  _SECRETSTOREHEALTHLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTOREHEALTHLISTREQUEST._options = None
  _SECRETSTOREHEALTHLISTREQUEST._serialized_options = b'\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _SECRETSTOREHEALTHLISTRESPONSE.fields_by_name['secret_store_healths']._options = None
  _SECRETSTOREHEALTHLISTRESPONSE.fields_by_name['secret_store_healths']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _SECRETSTOREHEALTHLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _SECRETSTOREHEALTHLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _SECRETSTOREHEALTHLISTRESPONSE._options = None
  _SECRETSTOREHEALTHLISTRESPONSE._serialized_options = b'\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider\372\370\263\007\005\250\363\263\007\001'
  _SECRETSTOREHEALTHCHECKREQUEST.fields_by_name['secret_store_id']._options = None
  _SECRETSTOREHEALTHCHECKREQUEST.fields_by_name['secret_store_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTOREHEALTHCHECKREQUEST._options = None
  _SECRETSTOREHEALTHCHECKREQUEST._serialized_options = b'\372\370\263\007\017\322\363\263\007\ngo_private'
  _SECRETSTOREHEALTHCHECKREQUEST.fields_by_name['secret_store_id']._options = None
  _SECRETSTOREHEALTHCHECKREQUEST.fields_by_name['secret_store_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTOREHEALTHCHECKREQUEST._options = None
  _SECRETSTOREHEALTHCHECKREQUEST._serialized_options = b'\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _SECRETSTOREHEALTHCHECKRESPONSE.fields_by_name['rate_limit']._options = None
  _SECRETSTOREHEALTHCHECKRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _SECRETSTOREHEALTHCHECKRESPONSE._options = None
  _SECRETSTOREHEALTHCHECKRESPONSE._serialized_options = b'\372\370\263\007\017\322\363\263\007\ngo_private\372\370\263\007\005\250\363\263\007\001'
  _SECRETSTOREHEALTHCHECKRESPONSE.fields_by_name['rate_limit']._options = None
  _SECRETSTOREHEALTHCHECKRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _SECRETSTOREHEALTHCHECKRESPONSE._options = None
  _SECRETSTOREHEALTHCHECKRESPONSE._serialized_options = b'\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider\372\370\263\007\005\250\363\263\007\001'
  _SECRETSTOREHEALTH.fields_by_name['secret_store_id']._options = None
  _SECRETSTOREHEALTH.fields_by_name['secret_store_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTOREHEALTH.fields_by_name['node_id']._options = None
  _SECRETSTOREHEALTH.fields_by_name['node_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTOREHEALTH.fields_by_name['status']._options = None
  _SECRETSTOREHEALTH.fields_by_name['status']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTOREHEALTH.fields_by_name['changed_at']._options = None
  _SECRETSTOREHEALTH.fields_by_name['changed_at']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTOREHEALTH.fields_by_name['checked_at']._options = None
  _SECRETSTOREHEALTH.fields_by_name['checked_at']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTOREHEALTH.fields_by_name['error']._options = None
  _SECRETSTOREHEALTH.fields_by_name['error']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTOREHEALTH.fields_by_name['reachability']._options = None
  _SECRETSTOREHEALTH.fields_by_name['reachability']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTOREHEALTH.fields_by_name['flags']._options = None
  _SECRETSTOREHEALTH.fields_by_name['flags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTOREHEALTH._options = None
  _SECRETSTOREHEALTH._serialized_options = b'\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider\372\370\263\007\005\250\363\263\007\001'
  _SECRETSTOREHEALTHS._options = None
  _SECRETSTOREHEALTHS._serialized_options = b'\312\371\263\007\026\302\371\263\007\021SecretStoreHealth\312\371\263\007\007\322\371\263\007\002x-\312\371\263\007\005\330\371\263\007\001\312\371\263\007\006\312\371\263\007\001*\312\371\263\007\030\312\371\263\007\023!terraform-provider'
  _SECRETSTOREHEALTHS.methods_by_name['List']._options = None
  _SECRETSTOREHEALTHS.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\035\252\363\263\007\030/v1/secret-store-healths'
  _SECRETSTOREHEALTHS.methods_by_name['Check']._options = None
  _SECRETSTOREHEALTHS.methods_by_name['Check']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\035\252\363\263\007\030/v1/secret-store-healths\202\371\263\007\017\312\371\263\007\ngo_private'
  _SECRETSTOREHEALTHS.methods_by_name['Healthcheck']._options = None
  _SECRETSTOREHEALTHS.methods_by_name['Healthcheck']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\035\252\363\263\007\030/v1/secret-store-healths'
  _SECRETSTOREHEALTHLISTREQUEST._serialized_start=95
  _SECRETSTOREHEALTHLISTREQUEST._serialized_end=234
  _SECRETSTOREHEALTHLISTRESPONSE._serialized_start=237
  _SECRETSTOREHEALTHLISTRESPONSE._serialized_end=514
  _SECRETSTOREHEALTHCHECKREQUEST._serialized_start=517
  _SECRETSTOREHEALTHCHECKREQUEST._serialized_end=648
  _SECRETSTOREHEALTHCHECKREQUEST._serialized_start=651
  _SECRETSTOREHEALTHCHECKREQUEST._serialized_end=802
  _SECRETSTOREHEALTHCHECKRESPONSE._serialized_start=805
  _SECRETSTOREHEALTHCHECKRESPONSE._serialized_end=1000
  _SECRETSTOREHEALTHCHECKRESPONSE._serialized_start=1003
  _SECRETSTOREHEALTHCHECKRESPONSE._serialized_end=1218
  _SECRETSTOREHEALTH._serialized_start=1221
  _SECRETSTOREHEALTH._serialized_end=1600
  _SECRETSTOREHEALTHS._serialized_start=1603
  _SECRETSTOREHEALTHS._serialized_end=2128
# @@protoc_insertion_point(module_scope)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: replays.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rreplays.proto\x12\x02v1\x1a\x1egoogle/protobuf/duration.proto\x1a\roptions.proto\x1a\nspec.proto\"\x80\x01\n\x11ReplayListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:(\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\xec\x01\n\x12ReplayListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12+\n\x06\x63hunks\x18\x02 \x03(\x0b\x32\x0f.v1.ReplayChunkB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:(\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\xb0\x01\n\x0bReplayChunk\x12\x18\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x30\n\x06\x65vents\x18\x02 \x03(\x0b\x32\x14.v1.ReplayChunkEventB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12!\n\rsymmetric_key\x18\x03 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:2\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\x99\x01\n\x10ReplayChunkEvent\x12\x18\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x37\n\x08\x64uration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:2\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider2\xad\x01\n\x07Replays\x12Y\n\x04List\x12\x15.v1.ReplayListRequest\x1a\x16.v1.ReplayListResponse\"\"\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x10\xaa\xf3\xb3\x07\x0b/v1/replays\x1aG\xca\xf9\xb3\x07\x10\xc2\xf9\xb3\x07\x0bReplayChunk\xca\xf9\xb3\x07\x05\xd8\xf9\xb3\x07\x01\xca\xf9\xb3\x07\x06\xca\xf9\xb3\x07\x01*\xca\xf9\xb3\x07\x18\xca\xf9\xb3\x07\x13!terraform-providerB\x8b\x01\n\x19\x63om.strongdm.api.plumbingB\x0fReplaysPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\xc2\x92\xb4\x07\x06\xa2\x8c\xb4\x07\x01*\xc2\x92\xb4\x07\x18\xa2\x8c\xb4\x07\x13!terraform-providerb\x06proto3')



_REPLAYLISTREQUEST = DESCRIPTOR.message_types_by_name['ReplayListRequest']
_REPLAYLISTRESPONSE = DESCRIPTOR.message_types_by_name['ReplayListResponse']
_REPLAYCHUNK = DESCRIPTOR.message_types_by_name['ReplayChunk']
_REPLAYCHUNKEVENT = DESCRIPTOR.message_types_by_name['ReplayChunkEvent']
ReplayListRequest = _reflection.GeneratedProtocolMessageType('ReplayListRequest', (_message.Message,), {
  'DESCRIPTOR' : _REPLAYLISTREQUEST,
  '__module__' : 'replays_pb2'
  # @@protoc_insertion_point(class_scope:v1.ReplayListRequest)
  })
_sym_db.RegisterMessage(ReplayListRequest)

ReplayListResponse = _reflection.GeneratedProtocolMessageType('ReplayListResponse', (_message.Message,), {
  'DESCRIPTOR' : _REPLAYLISTRESPONSE,
  '__module__' : 'replays_pb2'
  # @@protoc_insertion_point(class_scope:v1.ReplayListResponse)
  })
_sym_db.RegisterMessage(ReplayListResponse)

ReplayChunk = _reflection.GeneratedProtocolMessageType('ReplayChunk', (_message.Message,), {
  'DESCRIPTOR' : _REPLAYCHUNK,
  '__module__' : 'replays_pb2'
  # @@protoc_insertion_point(class_scope:v1.ReplayChunk)
  })
_sym_db.RegisterMessage(ReplayChunk)

ReplayChunkEvent = _reflection.GeneratedProtocolMessageType('ReplayChunkEvent', (_message.Message,), {
  'DESCRIPTOR' : _REPLAYCHUNKEVENT,
  '__module__' : 'replays_pb2'
  # @@protoc_insertion_point(class_scope:v1.ReplayChunkEvent)
  })
_sym_db.RegisterMessage(ReplayChunkEvent)

_REPLAYS = DESCRIPTOR.services_by_name['Replays']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\017ReplaysPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\302\222\264\007\006\242\214\264\007\001*\302\222\264\007\030\242\214\264\007\023!terraform-provider'
  _REPLAYLISTREQUEST.fields_by_name['filter']._options = None
  _REPLAYLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REPLAYLISTREQUEST._options = None
  _REPLAYLISTREQUEST._serialized_options = b'\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _REPLAYLISTRESPONSE.fields_by_name['chunks']._options = None
  _REPLAYLISTRESPONSE.fields_by_name['chunks']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _REPLAYLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _REPLAYLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _REPLAYLISTRESPONSE._options = None
  _REPLAYLISTRESPONSE._serialized_options = b'\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _REPLAYCHUNK.fields_by_name['data']._options = None
  _REPLAYCHUNK.fields_by_name['data']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REPLAYCHUNK.fields_by_name['events']._options = None
  _REPLAYCHUNK.fields_by_name['events']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REPLAYCHUNK.fields_by_name['symmetric_key']._options = None
  _REPLAYCHUNK.fields_by_name['symmetric_key']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REPLAYCHUNK._options = None
  _REPLAYCHUNK._serialized_options = b'\372\370\263\007\005\250\363\263\007\001\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _REPLAYCHUNKEVENT.fields_by_name['data']._options = None
  _REPLAYCHUNKEVENT.fields_by_name['data']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REPLAYCHUNKEVENT.fields_by_name['duration']._options = None
  _REPLAYCHUNKEVENT.fields_by_name['duration']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REPLAYCHUNKEVENT._options = None
  _REPLAYCHUNKEVENT._serialized_options = b'\372\370\263\007\005\250\363\263\007\001\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _REPLAYS._options = None
  _REPLAYS._serialized_options = b'\312\371\263\007\020\302\371\263\007\013ReplayChunk\312\371\263\007\005\330\371\263\007\001\312\371\263\007\006\312\371\263\007\001*\312\371\263\007\030\312\371\263\007\023!terraform-provider'
  _REPLAYS.methods_by_name['List']._options = None
  _REPLAYS.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\020\252\363\263\007\013/v1/replays'
  _REPLAYLISTREQUEST._serialized_start=81
  _REPLAYLISTREQUEST._serialized_end=209
  _REPLAYLISTRESPONSE._serialized_start=212
  _REPLAYLISTRESPONSE._serialized_end=448
  _REPLAYCHUNK._serialized_start=451
  _REPLAYCHUNK._serialized_end=627
  _REPLAYCHUNKEVENT._serialized_start=630
  _REPLAYCHUNKEVENT._serialized_end=783
  _REPLAYS._serialized_start=786
  _REPLAYS._serialized_end=959
# @@protoc_insertion_point(module_scope)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: groups.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import accounts_pb2 as accounts__pb2
from . import approval_workflows_pb2 as approval__workflows__pb2
from . import options_pb2 as options__pb2
from . import roles_pb2 as roles__pb2
from . import spec_pb2 as spec__pb2
from . import tags_pb2 as tags__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cgroups.proto\x12\x02v1\x1a\x0e\x61\x63\x63ounts.proto\x1a\x18\x61pproval_workflows.proto\x1a\roptions.proto\x1a\x0broles.proto\x1a\nspec.proto\x1a\ntags.proto\"}\n\x12GroupCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12$\n\x05group\x18\x02 \x01(\x0b\x32\t.v1.GroupB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\xb6\x01\n\x13GroupCreateResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadata\x12$\n\x05group\x18\x02 \x01(\x0b\x32\t.v1.GroupB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\x9a\x01\n\x1bGroupCreateFromRolesRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12\x1c\n\x08role_ids\x18\x02 \x03(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1a\n\x06\x63ommit\x18\x03 \x01(\x08\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\xd1\x01\n\x1cGroupCreateFromRolesResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadata\x12\x35\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x36\n\x0fgroup_from_role\x18\x03 \x03(\x0b\x32\x11.v1.GroupFromRoleB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\x8c\x02\n\rGroupFromRole\x12\x35\n\nrate_limit\x18\x01 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\"\n\x04role\x18\x02 \x01(\x0b\x32\x08.v1.RoleB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x05group\x18\x03 \x01(\x0b\x32\t.v1.GroupB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12&\n\x08\x61\x63\x63ounts\x18\x04 \x03(\x0b\x32\x08.v1.UserB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x38\n\x0e\x61pproval_flows\x18\x05 \x03(\x0b\x32\x14.v1.ApprovalWorkflowB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"i\n\x0fGroupGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\xbc\x01\n\x10GroupGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x05group\x18\x02 \x01(\x0b\x32\t.v1.GroupB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\x89\x01\n\x12GroupUpdateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.UpdateRequestMetadata\x12\n\n\x02id\x18\x02 \x01(\t\x12$\n\x05group\x18\x03 \x01(\x0b\x32\t.v1.GroupB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\xb6\x01\n\x13GroupUpdateResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.UpdateResponseMetadata\x12$\n\x05group\x18\x02 \x01(\x0b\x32\t.v1.GroupB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"o\n\x12GroupDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.DeleteRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\x9c\x01\n\x13GroupDeleteResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"o\n\x10GroupListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\xb3\x01\n\x11GroupListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12%\n\x06groups\x18\x02 \x03(\x0b\x32\t.v1.GroupB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\x8c\x02\n\x05Group\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\x1f\n\x0b\x64\x65scription\x18\x03 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1f\n\x06source\x18\x04 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\x12\"\n\x04tags\x18\x05 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:f\xfa\xf8\xb3\x07\x61\xa8\xf3\xb3\x07\x01\xc2\xf3\xb3\x07I\xa2\xf3\xb3\x07\x1etf_examples/group_resource.txt\xaa\xf3\xb3\x07!tf_examples/group_data_source.txt\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li2\x9c\x05\n\x06Groups\x12]\n\x06\x43reate\x12\x16.v1.GroupCreateRequest\x1a\x17.v1.GroupCreateResponse\"\"\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x0f\xaa\xf3\xb3\x07\n/v1/groups\x12\x83\x01\n\x0f\x43reateFromRoles\x12\x1f.v1.GroupCreateFromRolesRequest\x1a .v1.GroupCreateFromRolesResponse\"-\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x1a\xaa\xf3\xb3\x07\x15/v1/groups/from-roles\x12X\n\x03Get\x12\x13.v1.GroupGetRequest\x1a\x14.v1.GroupGetResponse\"&\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x14\xaa\xf3\xb3\x07\x0f/v1/groups/{id}\x12\x61\n\x06Update\x12\x16.v1.GroupUpdateRequest\x1a\x17.v1.GroupUpdateResponse\"&\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03put\x82\xf9\xb3\x07\x14\xaa\xf3\xb3\x07\x0f/v1/groups/{id}\x12\x64\n\x06\x44\x65lete\x12\x16.v1.GroupDeleteRequest\x1a\x17.v1.GroupDeleteResponse\")\x82\xf9\xb3\x07\x0b\xa2\xf3\xb3\x07\x06\x64\x65lete\x82\xf9\xb3\x07\x14\xaa\xf3\xb3\x07\x0f/v1/groups/{id}\x12V\n\x04List\x12\x14.v1.GroupListRequest\x1a\x15.v1.GroupListResponse\"!\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x0f\xaa\xf3\xb3\x07\n/v1/groups\x1a\x32\xca\xf9\xb3\x07#\xc2\xf9\xb3\x07\x05Group\xca\xf9\xb3\x07\x01*\xca\xf9\xb3\x07\x03\x63li\xd2\xf9\xb3\x07\x06group-\xca\xf9\xb3\x07\x05\xe8\xf9\xb3\x07\x01\x42z\n\x19\x63om.strongdm.api.plumbingB\x0eGroupsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\xc2\x92\xb4\x07\x06\xa2\x8c\xb4\x07\x01*\xc2\x92\xb4\x07\x08\xa2\x8c\xb4\x07\x03\x63lib\x06proto3')



_GROUPCREATEREQUEST = DESCRIPTOR.message_types_by_name['GroupCreateRequest']
_GROUPCREATERESPONSE = DESCRIPTOR.message_types_by_name['GroupCreateResponse']
_GROUPCREATEFROMROLESREQUEST = DESCRIPTOR.message_types_by_name['GroupCreateFromRolesRequest']
_GROUPCREATEFROMROLESRESPONSE = DESCRIPTOR.message_types_by_name['GroupCreateFromRolesResponse']
_GROUPFROMROLE = DESCRIPTOR.message_types_by_name['GroupFromRole']
_GROUPGETREQUEST = DESCRIPTOR.message_types_by_name['GroupGetRequest']
_GROUPGETRESPONSE = DESCRIPTOR.message_types_by_name['GroupGetResponse']
_GROUPUPDATEREQUEST = DESCRIPTOR.message_types_by_name['GroupUpdateRequest']
_GROUPUPDATERESPONSE = DESCRIPTOR.message_types_by_name['GroupUpdateResponse']
_GROUPDELETEREQUEST = DESCRIPTOR.message_types_by_name['GroupDeleteRequest']
_GROUPDELETERESPONSE = DESCRIPTOR.message_types_by_name['GroupDeleteResponse']
_GROUPLISTREQUEST = DESCRIPTOR.message_types_by_name['GroupListRequest']
_GROUPLISTRESPONSE = DESCRIPTOR.message_types_by_name['GroupListResponse']
_GROUP = DESCRIPTOR.message_types_by_name['Group']
GroupCreateRequest = _reflection.GeneratedProtocolMessageType('GroupCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _GROUPCREATEREQUEST,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupCreateRequest)
  })
_sym_db.RegisterMessage(GroupCreateRequest)

GroupCreateResponse = _reflection.GeneratedProtocolMessageType('GroupCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _GROUPCREATERESPONSE,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupCreateResponse)
  })
_sym_db.RegisterMessage(GroupCreateResponse)

GroupCreateFromRolesRequest = _reflection.GeneratedProtocolMessageType('GroupCreateFromRolesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GROUPCREATEFROMROLESREQUEST,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupCreateFromRolesRequest)
  })
_sym_db.RegisterMessage(GroupCreateFromRolesRequest)

GroupCreateFromRolesResponse = _reflection.GeneratedProtocolMessageType('GroupCreateFromRolesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GROUPCREATEFROMROLESRESPONSE,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupCreateFromRolesResponse)
  })
_sym_db.RegisterMessage(GroupCreateFromRolesResponse)

GroupFromRole = _reflection.GeneratedProtocolMessageType('GroupFromRole', (_message.Message,), {
  'DESCRIPTOR' : _GROUPFROMROLE,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupFromRole)
  })
_sym_db.RegisterMessage(GroupFromRole)

GroupGetRequest = _reflection.GeneratedProtocolMessageType('GroupGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GROUPGETREQUEST,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupGetRequest)
  })
_sym_db.RegisterMessage(GroupGetRequest)

GroupGetResponse = _reflection.GeneratedProtocolMessageType('GroupGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _GROUPGETRESPONSE,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupGetResponse)
  })
_sym_db.RegisterMessage(GroupGetResponse)

GroupUpdateRequest = _reflection.GeneratedProtocolMessageType('GroupUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _GROUPUPDATEREQUEST,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupUpdateRequest)
  })
_sym_db.RegisterMessage(GroupUpdateRequest)

GroupUpdateResponse = _reflection.GeneratedProtocolMessageType('GroupUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _GROUPUPDATERESPONSE,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupUpdateResponse)
  })
_sym_db.RegisterMessage(GroupUpdateResponse)

GroupDeleteRequest = _reflection.GeneratedProtocolMessageType('GroupDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _GROUPDELETEREQUEST,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupDeleteRequest)
  })
_sym_db.RegisterMessage(GroupDeleteRequest)

GroupDeleteResponse = _reflection.GeneratedProtocolMessageType('GroupDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _GROUPDELETERESPONSE,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupDeleteResponse)
  })
_sym_db.RegisterMessage(GroupDeleteResponse)

GroupListRequest = _reflection.GeneratedProtocolMessageType('GroupListRequest', (_message.Message,), {
  'DESCRIPTOR' : _GROUPLISTREQUEST,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupListRequest)
  })
_sym_db.RegisterMessage(GroupListRequest)

GroupListResponse = _reflection.GeneratedProtocolMessageType('GroupListResponse', (_message.Message,), {
  'DESCRIPTOR' : _GROUPLISTRESPONSE,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupListResponse)
  })
_sym_db.RegisterMessage(GroupListResponse)

Group = _reflection.GeneratedProtocolMessageType('Group', (_message.Message,), {
  'DESCRIPTOR' : _GROUP,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.Group)
  })
_sym_db.RegisterMessage(Group)

_GROUPS = DESCRIPTOR.services_by_name['Groups']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\016GroupsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\302\222\264\007\006\242\214\264\007\001*\302\222\264\007\010\242\214\264\007\003cli'
  _GROUPCREATEREQUEST.fields_by_name['group']._options = None
  _GROUPCREATEREQUEST.fields_by_name['group']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPCREATEREQUEST._options = None
  _GROUPCREATEREQUEST._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPCREATERESPONSE.fields_by_name['group']._options = None
  _GROUPCREATERESPONSE.fields_by_name['group']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPCREATERESPONSE.fields_by_name['rate_limit']._options = None
  _GROUPCREATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPCREATERESPONSE._options = None
  _GROUPCREATERESPONSE._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPCREATEFROMROLESREQUEST.fields_by_name['role_ids']._options = None
  _GROUPCREATEFROMROLESREQUEST.fields_by_name['role_ids']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPCREATEFROMROLESREQUEST.fields_by_name['commit']._options = None
  _GROUPCREATEFROMROLESREQUEST.fields_by_name['commit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPCREATEFROMROLESREQUEST._options = None
  _GROUPCREATEFROMROLESREQUEST._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPCREATEFROMROLESRESPONSE.fields_by_name['rate_limit']._options = None
  _GROUPCREATEFROMROLESRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPCREATEFROMROLESRESPONSE.fields_by_name['group_from_role']._options = None
  _GROUPCREATEFROMROLESRESPONSE.fields_by_name['group_from_role']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPCREATEFROMROLESRESPONSE._options = None
  _GROUPCREATEFROMROLESRESPONSE._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPFROMROLE.fields_by_name['rate_limit']._options = None
  _GROUPFROMROLE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPFROMROLE.fields_by_name['role']._options = None
  _GROUPFROMROLE.fields_by_name['role']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPFROMROLE.fields_by_name['group']._options = None
  _GROUPFROMROLE.fields_by_name['group']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPFROMROLE.fields_by_name['accounts']._options = None
  _GROUPFROMROLE.fields_by_name['accounts']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPFROMROLE.fields_by_name['approval_flows']._options = None
  _GROUPFROMROLE.fields_by_name['approval_flows']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPFROMROLE._options = None
  _GROUPFROMROLE._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPGETREQUEST.fields_by_name['id']._options = None
  _GROUPGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPGETREQUEST._options = None
  _GROUPGETREQUEST._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPGETRESPONSE.fields_by_name['meta']._options = None
  _GROUPGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPGETRESPONSE.fields_by_name['group']._options = None
  _GROUPGETRESPONSE.fields_by_name['group']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPGETRESPONSE.fields_by_name['rate_limit']._options = None
  _GROUPGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPGETRESPONSE._options = None
  _GROUPGETRESPONSE._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPUPDATEREQUEST.fields_by_name['group']._options = None
  _GROUPUPDATEREQUEST.fields_by_name['group']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPUPDATEREQUEST._options = None
  _GROUPUPDATEREQUEST._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPUPDATERESPONSE.fields_by_name['group']._options = None
  _GROUPUPDATERESPONSE.fields_by_name['group']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPUPDATERESPONSE.fields_by_name['rate_limit']._options = None
  _GROUPUPDATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPUPDATERESPONSE._options = None
  _GROUPUPDATERESPONSE._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPDELETEREQUEST.fields_by_name['id']._options = None
  _GROUPDELETEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPDELETEREQUEST._options = None
  _GROUPDELETEREQUEST._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPDELETERESPONSE.fields_by_name['meta']._options = None
  _GROUPDELETERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPDELETERESPONSE.fields_by_name['rate_limit']._options = None
  _GROUPDELETERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPDELETERESPONSE._options = None
  _GROUPDELETERESPONSE._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPLISTREQUEST.fields_by_name['filter']._options = None
  _GROUPLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPLISTREQUEST._options = None
  _GROUPLISTREQUEST._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPLISTRESPONSE.fields_by_name['groups']._options = None
  _GROUPLISTRESPONSE.fields_by_name['groups']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _GROUPLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _GROUPLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPLISTRESPONSE._options = None
  _GROUPLISTRESPONSE._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUP.fields_by_name['id']._options = None
  _GROUP.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUP.fields_by_name['name']._options = None
  _GROUP.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _GROUP.fields_by_name['description']._options = None
  _GROUP.fields_by_name['description']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUP.fields_by_name['source']._options = None
  _GROUP.fields_by_name['source']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\230\364\263\007\001'
  _GROUP.fields_by_name['tags']._options = None
  _GROUP.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUP._options = None
  _GROUP._serialized_options = b'\372\370\263\007a\250\363\263\007\001\302\363\263\007I\242\363\263\007\036tf_examples/group_resource.txt\252\363\263\007!tf_examples/group_data_source.txt\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPS._options = None
  _GROUPS._serialized_options = b'\312\371\263\007#\302\371\263\007\005Group\312\371\263\007\001*\312\371\263\007\003cli\322\371\263\007\006group-\312\371\263\007\005\350\371\263\007\001'
  _GROUPS.methods_by_name['Create']._options = None
  _GROUPS.methods_by_name['Create']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\017\252\363\263\007\n/v1/groups'
  _GROUPS.methods_by_name['CreateFromRoles']._options = None
  _GROUPS.methods_by_name['CreateFromRoles']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\032\252\363\263\007\025/v1/groups/from-roles'
  _GROUPS.methods_by_name['Get']._options = None
  _GROUPS.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\024\252\363\263\007\017/v1/groups/{id}'
  _GROUPS.methods_by_name['Update']._options = None
  _GROUPS.methods_by_name['Update']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003put\202\371\263\007\024\252\363\263\007\017/v1/groups/{id}'
  _GROUPS.methods_by_name['Delete']._options = None
  _GROUPS.methods_by_name['Delete']._serialized_options = b'\202\371\263\007\013\242\363\263\007\006delete\202\371\263\007\024\252\363\263\007\017/v1/groups/{id}'
  _GROUPS.methods_by_name['List']._options = None
  _GROUPS.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\017\252\363\263\007\n/v1/groups'
  _GROUPCREATEREQUEST._serialized_start=114
  _GROUPCREATEREQUEST._serialized_end=239
  _GROUPCREATERESPONSE._serialized_start=242
  _GROUPCREATERESPONSE._serialized_end=424
  _GROUPCREATEFROMROLESREQUEST._serialized_start=427
  _GROUPCREATEFROMROLESREQUEST._serialized_end=581
  _GROUPCREATEFROMROLESRESPONSE._serialized_start=584
  _GROUPCREATEFROMROLESRESPONSE._serialized_end=793
  _GROUPFROMROLE._serialized_start=796
  _GROUPFROMROLE._serialized_end=1064
  _GROUPGETREQUEST._serialized_start=1066
  _GROUPGETREQUEST._serialized_end=1171
  _GROUPGETRESPONSE._serialized_start=1174
  _GROUPGETRESPONSE._serialized_end=1362
  _GROUPUPDATEREQUEST._serialized_start=1365
  _GROUPUPDATEREQUEST._serialized_end=1502
  _GROUPUPDATERESPONSE._serialized_start=1505
  _GROUPUPDATERESPONSE._serialized_end=1687
  _GROUPDELETEREQUEST._serialized_start=1689
  _GROUPDELETEREQUEST._serialized_end=1800
  _GROUPDELETERESPONSE._serialized_start=1803
  _GROUPDELETERESPONSE._serialized_end=1959
  _GROUPLISTREQUEST._serialized_start=1961
  _GROUPLISTREQUEST._serialized_end=2072
  _GROUPLISTRESPONSE._serialized_start=2075
  _GROUPLISTRESPONSE._serialized_end=2254
  _GROUP._serialized_start=2257
  _GROUP._serialized_end=2525
  _GROUPS._serialized_start=2528
  _GROUPS._serialized_end=3196
# @@protoc_insertion_point(module_scope)
